---
title: OpenLink
description: JSON Schema for the OpenLink action.
---

Open a URL via the host.

```json
{
  "type": "object",
  "properties": {
    "action": {
      "const": "openLink",
      "default": "openLink",
      "type": "string"
    },
    "url": {
      "description": "URL to open",
      "type": "string"
    }
  },
  "required": [
    "action",
    "url"
  ]
}
```
